IpRecvControlData

Struct IpRecvControlData 

pub struct IpRecvControlData {
    pub tos: Option<u8>,
    pub ttl: Option<u8>,
    pub original_destination_address: Option<SocketAddress>,
    /* private fields */
}

Fields

tos: Option<u8>

The Type of Service value found in a received packet’s IPv4 header.

Present if the SOL_IP -> IP_RECVTOS option is enabled.

ttl: Option<u8>

The Time to Live value found in a received packet’s IPv4 header.

Present if the SOL_IP -> IP_RECVTTL option is enabled.

original_destination_address: Option<SocketAddress>

The original destination address.

Present if the SOL_IP -> IP_RECVORIGDSTADDR option is enabled.